==> jc-1.4.0.tar.gz: gnu/java/net/CRLFInputStream.h <==
// public class gnu.java.net.CRLFInputStream

// class file dependencies
// @dep_class ea533b701af44000 gnu_java_net_CRLFInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_CRLFInputStream_H_
#define _JC_gnu_java_net_CRLFInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_CRLFInputStream$sub_refs	_jc_gnu_java_net_CRLFInputStream$sub_refs;
typedef struct _jc_gnu_java_net_CRLFInputStream$sub_nonrefs	_jc_gnu_java_net_CRLFInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_CRLFInputStream$refs	_jc_gnu_java_net_CRLFInputStream$refs;
typedef struct _jc_gnu_java_net_CRLFInputStream$nonrefs	_jc_gnu_java_net_CRLFInputStream$nonrefs;
typedef struct _jc_gnu_java_net_CRLFInputStream$object	_jc_gnu_java_net_CRLFInputStream$object;

typedef struct _jc_gnu_java_net_CRLFInputStream$fields_struct	_jc_gnu_java_net_CRLFInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_CRLFInputStream$vmethods	_jc_gnu_java_net_CRLFInputStream$vmethods;
typedef const struct _jc_gnu_java_net_CRLFInputStream$vtable	_jc_gnu_java_net_CRLFInputStream$vtable;
typedef const struct _jc_gnu_java_net_CRLFInputStream$vtype	_jc_gnu_java_net_CRLFInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_CRLFInputStream$fields_struct {
	jint	CR;
	jint	LF;
};
extern _jc_gnu_java_net_CRLFInputStream$fields_struct _jc_gnu_java_net_CRLFInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_CRLFInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_CRLFInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, jint);
extern jboolean _jc_gnu_java_net_CRLFInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
extern jint _jc_gnu_java_net_CRLFInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
extern jint _jc_gnu_java_net_CRLFInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *);
extern jint _jc_gnu_java_net_CRLFInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint);
extern jint _jc_gnu_java_net_CRLFInputStream$method$removeCRLF$a436f2d244e7aef0(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_gnu_java_net_CRLFInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
extern void _jc_gnu_java_net_CRLFInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$removeCRLF$a436f2d244e7aef0;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_net_CRLFInputStream$vmethods {
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, jint);
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint);
	jint	(*removeCRLF$a436f2d244e7aef0)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_CRLFInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_CRLFInputStream$vmethods	gnu_java_net_CRLFInputStream;
};

// Vtype
struct _jc_gnu_java_net_CRLFInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_CRLFInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_CRLFInputStream$refs {
    _jc_gnu_java_net_CRLFInputStream$sub_refs	gnu_java_net_CRLFInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFInputStream$sub_nonrefs {
	jint	buf;
	jint	markBuf;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_CRLFInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_CRLFInputStream$sub_nonrefs	gnu_java_net_CRLFInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_CRLFInputStream$object {
	_jc_gnu_java_net_CRLFInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_CRLFInputStream$vtype	*vtype;
	_jc_gnu_java_net_CRLFInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_CRLFInputStream$vtype _jc_gnu_java_net_CRLFInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_CRLFInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_CRLFInputStream$class_object;

#endif	/* _JC_gnu_java_net_CRLFInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/CRLFInputStream.h <==
// public class gnu.java.net.CRLFInputStream

// class file dependencies
// @dep_class 706365b3527e8505 gnu_java_net_CRLFInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_CRLFInputStream_H_
#define _JC_gnu_java_net_CRLFInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_CRLFInputStream$sub_refs	_jc_gnu_java_net_CRLFInputStream$sub_refs;
typedef struct _jc_gnu_java_net_CRLFInputStream$sub_nonrefs	_jc_gnu_java_net_CRLFInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_CRLFInputStream$refs	_jc_gnu_java_net_CRLFInputStream$refs;
typedef struct _jc_gnu_java_net_CRLFInputStream$nonrefs	_jc_gnu_java_net_CRLFInputStream$nonrefs;
typedef struct _jc_gnu_java_net_CRLFInputStream$object	_jc_gnu_java_net_CRLFInputStream$object;

typedef struct _jc_gnu_java_net_CRLFInputStream$fields_struct	_jc_gnu_java_net_CRLFInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_CRLFInputStream$vmethods	_jc_gnu_java_net_CRLFInputStream$vmethods;
typedef const struct _jc_gnu_java_net_CRLFInputStream$vtable	_jc_gnu_java_net_CRLFInputStream$vtable;
typedef const struct _jc_gnu_java_net_CRLFInputStream$vtype	_jc_gnu_java_net_CRLFInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_CRLFInputStream$fields_struct {
	jint	CR;
	jint	LF;
};
extern _jc_gnu_java_net_CRLFInputStream$fields_struct _jc_gnu_java_net_CRLFInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_CRLFInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_CRLFInputStream$method$indexOfCRLF$035f1647ba87b952(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_CRLFInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_CRLFInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_CRLFInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$indexOfCRLF$035f1647ba87b952;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_CRLFInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_CRLFInputStream$vmethods {
	jint	(*indexOfCRLF$035f1647ba87b952)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_CRLFInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_CRLFInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_CRLFInputStream$vmethods	gnu_java_net_CRLFInputStream;
};

// Vtype
struct _jc_gnu_java_net_CRLFInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_CRLFInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_CRLFInputStream$refs {
    _jc_gnu_java_net_CRLFInputStream$sub_refs	gnu_java_net_CRLFInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFInputStream$sub_nonrefs {
	jboolean	doReset;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_CRLFInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_CRLFInputStream$sub_nonrefs	gnu_java_net_CRLFInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_CRLFInputStream$object {
	_jc_gnu_java_net_CRLFInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_CRLFInputStream$vtype	*vtype;
	_jc_gnu_java_net_CRLFInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_CRLFInputStream$vtype _jc_gnu_java_net_CRLFInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_CRLFInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_CRLFInputStream$class_object;

#endif	/* _JC_gnu_java_net_CRLFInputStream_H_ */
